% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotRegion1D.R
\name{plotRegion1D}
\alias{plotRegion1D}
\alias{plotRegion1D,LipidTrendSE-method}
\title{Plot region trends for one-dimensional lipid feature}
\usage{
plotRegion1D(object, p_cutoff = 0.05, y_scale = "identity")

\S4method{plotRegion1D}{LipidTrendSE}(object, p_cutoff = 0.05, y_scale = "identity")
}
\arguments{
\item{object}{A LipidTrendSE object containing analysis results.}

\item{p_cutoff}{Numeric. Significance level. The range is 0 to 1.
Default is \code{0.05}.}

\item{y_scale}{Character. Choose one of the y-axis scales: "identity",
"log2", "log10", or "sqrt". Default is \code{"identity"}.}
}
\value{
For split chain analyses, a list with two elements:
\item{even_result}{Plot for even chain features, or NULL if none exist}
\item{odd_result}{Plot for odd chain features, or NULL if none exist}
For non-split analyses, a single plot.
}
\description{
Visualize analysis results for one-dimensional features to
identify lipid feature tendencies. The plots highlight regions of significant
differences between case and control samples: blue areas indicate
significantly lower abundance in case samples, while red areas indicate
significantly higher abundance.
}
\examples{
data("lipid_se_CL")
res_se <- analyzeLipidRegion(
    lipid_se=lipid_se_CL, ref_group="sgCtrl", split_chain=FALSE,
    chain_col=NULL, radius=2, own_contri=0.5, permute_time=100,
    abund_weight=TRUE)
plot <- plotRegion1D(res_se, p_cutoff=0.05, y_scale='identity')
}
\seealso{
\code{\link{analyzeLipidRegion}} for generating the input LipidTrendSE object
}
